@@ -2,6 +2,42 @@ import requests
 
 SR = "https://some-random-api.ml"
 
+class Lyrics:
+	def __init__(self , x: dict):
+		self.raw_data = x
+
+	@property
+	def title(self):
+		return self.raw_data['title']
+
+	@property
+	def author(self):
+		return self.raw_data['author']
+
+	@property
+	def lyrics(self):
+		return self.raw_data['lyrics']
+
+	@property
+	def thumbnail_url(self):
+		return self.raw_data['thumbnail']
+
+	def save_thumbnail(self , filename=None):
+		try:
+			if filename is None:
+				filename = self.image_url.split('/')[-1]
+			r = requests.get(self.image_url , allow_redirects = True)
+			open(filename , 'wb').write(r.content)
+			return True
+		except:
+			return False
+
+	def save_lyrics(self , filename=None):
+		if filename is None:
+			print(self.lyrics , file=open(f'{self.title}.txt' , 'w'))
+		else:
+			print(self.lyrics , file=open(filename , "w"))
+
 class Meme():
 	def __init__(self , meme_: dict):
 		self.caption_ = meme_['caption']
@@ -79,4 +115,6 @@ def bot_token(id_=None):
 def lyrics(title: str):
 	title = title.replace(' ', '%20')
 	r = requests.request("GET", f"{SR}/lyrics?title={title}").json()
-	return r
\ No newline at end of file
+	x = {"title": f'{r["title"]}' , "author": r['author'] , "lyrics": r['lyrics'] , "thumbnail": r['thumbnail']['genius']}
+
+	return Lyrics(x)
\ No newline at end of file
